@@ -103,7 +103,6 @@
 //!
 //! [tc39/test262]:https://github.com/tc39/test262
 
-#![cfg_attr(test, feature(bench_black_box))]
 #![cfg_attr(test, feature(test))]
 #![deny(unused)]
 
@@ -128,6 +127,8 @@ pub enum Syntax {
     /// Standard
     #[serde(rename = "ecmascript")]
     Es(EsConfig),
+    /// This variant requires the cargo feature `typescript` to be enabled.
+    #[cfg(feature = "typescript")]
     #[serde(rename = "typescript")]
     Typescript(TsConfig),
 }
@@ -231,7 +232,14 @@ impl Syntax {
     }
 
     /// Should we pare typescript?
-    pub fn typescript(self) -> bool {
+    #[cfg(not(feature = "typescript"))]
+    pub const fn typescript(self) -> bool {
+        false
+    }
+
+    /// Should we pare typescript?
+    #[cfg(feature = "typescript")]
+    pub const fn typescript(self) -> bool {
         match self {
             Syntax::Typescript(..) => true,
             _ => false,
