@@ -232,6 +232,9 @@ impl<'a, I: Tokens> Parser<I> {
                 tok!("import") => {
                     let import = self.parse_ident_name()?;
                     if self.input.syntax().import_meta() && is!(self, '.') {
+                        if !self.ctx().module {
+                            syntax_error!(self, SyntaxError::ImportMetaInScript);
+                        }
                         return self
                             .parse_import_meta_prop(import)
                             .map(Expr::MetaProp)
